@@ -22,20 +22,9 @@
    Authors: John Sullivan <sullivan@eazel.com>
 */
 
-#ifndef EEL_GLIB_EXTENSIONS_H
-#define EEL_GLIB_EXTENSIONS_H
+#pragma once
 
 #include <glib.h>
 
 /* A gboolean variant for bit fields. */
 typedef guint eel_boolean_bit;
-
-/* GList functions. */
-gboolean    eel_g_lists_sort_and_check_for_intersection (GList                **list_a,
-							 GList                **list_b);
-
-/* NULL terminated string arrays (strv). */
-gboolean    eel_g_strv_equal                            (char                 **a,
-							 char                 **b);
-
-#endif /* EEL_GLIB_EXTENSIONS_H */
