@@ -55,7 +55,7 @@ enum
 static guint signals[LAST_SIGNAL];
 
 /* forward declarations */
-#define NAUTILUS_BOOKMARK_LIST_ERROR (nautilus_bookmark_list_error_quark())
+#define NAUTILUS_BOOKMARK_LIST_ERROR (nautilus_bookmark_list_error_quark ())
 static GQuark      nautilus_bookmark_list_error_quark (void);
 
 static void        nautilus_bookmark_list_load_file (NautilusBookmarkList *bookmarks);
@@ -70,7 +70,8 @@ nautilus_bookmark_list_error_quark (void)
 }
 
 static NautilusBookmark *
-new_bookmark_from_uri (const char *uri, const char *label)
+new_bookmark_from_uri (const char *uri,
+                       const char *label)
 {
     NautilusBookmark *new_bookmark = NULL;
     g_autoptr (GFile) location = NULL;
@@ -351,8 +352,9 @@ load_callback (GObject      *source_object,
         /* Ignore empty or invalid lines that cannot be parsed properly */
         if (lines[i][0] != '\0' && lines[i][0] != ' ')
         {
-            /* gtk 2.7/2.8 might have labels appended to bookmarks which are separated by a space */
-            /* we must seperate the bookmark uri and the potential label */
+            /* gtk 2.7/2.8 might have labels appended to bookmarks which are separated by a space
+             * we must seperate the bookmark uri and the potential label
+             */
             char *space;
             g_autofree char *label = NULL;
 
@@ -469,7 +471,8 @@ save_io_thread (GTask        *task,
     parent = g_file_get_parent (file);
     path = g_file_get_path (parent);
 
-    if (g_mkdir_with_parents (path, 0700) == -1) {
+    if (g_mkdir_with_parents (path, 0700) == -1)
+    {
         int saved_errno = errno;
 
         g_set_error (&error, NAUTILUS_BOOKMARK_LIST_ERROR, 0,
