@@ -22,8 +22,7 @@
  *          Cosimo Cecchi <cosimoc@redhat.com>
  */
 
-#ifndef NAUTILUS_BOOKMARK_H
-#define NAUTILUS_BOOKMARK_H
+#pragma once
 
 #include <gtk/gtk.h>
 #include <gio/gio.h>
@@ -55,6 +54,4 @@ char *                nautilus_bookmark_get_scroll_pos         (NautilusBookmark
 /* Helper functions for displaying bookmarks */
 GtkWidget *           nautilus_bookmark_menu_item_new          (NautilusBookmark      *bookmark);
 
-G_END_DECLS
-
-#endif /* NAUTILUS_BOOKMARK_H */
+G_END_DECLS
\ No newline at end of file
