@@ -27,8 +27,10 @@
 
 #define HOVER_HIDE_TIMEOUT_INTERVAL 100
 
-struct _NautilusFloatingBarDetails
+struct _NautilusFloatingBar
 {
+    GtkBox parent;
+
     gchar *primary_label;
     gchar *details_label;
 
@@ -78,8 +80,8 @@ nautilus_floating_bar_finalize (GObject *obj)
     NautilusFloatingBar *self = NAUTILUS_FLOATING_BAR (obj);
 
     nautilus_floating_bar_remove_hover_timeout (self);
-    g_free (self->priv->primary_label);
-    g_free (self->priv->details_label);
+    g_free (self->primary_label);
+    g_free (self->details_label);
 
     G_OBJECT_CLASS (nautilus_floating_bar_parent_class)->finalize (obj);
 }
@@ -96,19 +98,19 @@ nautilus_floating_bar_get_property (GObject    *object,
     {
         case PROP_PRIMARY_LABEL:
         {
-            g_value_set_string (value, self->priv->primary_label);
+            g_value_set_string (value, self->primary_label);
         }
         break;
 
         case PROP_DETAILS_LABEL:
         {
-            g_value_set_string (value, self->priv->details_label);
+            g_value_set_string (value, self->details_label);
         }
         break;
 
         case PROP_SHOW_SPINNER:
         {
-            g_value_set_boolean (value, self->priv->show_spinner);
+            g_value_set_boolean (value, self->show_spinner);
         }
         break;
 
@@ -161,27 +163,27 @@ update_labels (NautilusFloatingBar *self)
 {
     gboolean primary_visible, details_visible;
 
-    primary_visible = (self->priv->primary_label != NULL) &&
-                      (strlen (self->priv->primary_label) > 0);
-    details_visible = (self->priv->details_label != NULL) &&
-                      (strlen (self->priv->details_label) > 0);
+    primary_visible = (self->primary_label != NULL) &&
+                      (strlen (self->primary_label) > 0);
+    details_visible = (self->details_label != NULL) &&
+                      (strlen (self->details_label) > 0);
 
-    gtk_label_set_text (GTK_LABEL (self->priv->primary_label_widget),
-                        self->priv->primary_label);
-    gtk_widget_set_visible (self->priv->primary_label_widget, primary_visible);
+    gtk_label_set_text (GTK_LABEL (self->primary_label_widget),
+                        self->primary_label);
+    gtk_widget_set_visible (self->primary_label_widget, primary_visible);
 
-    gtk_label_set_text (GTK_LABEL (self->priv->details_label_widget),
-                        self->priv->details_label);
-    gtk_widget_set_visible (self->priv->details_label_widget, details_visible);
+    gtk_label_set_text (GTK_LABEL (self->details_label_widget),
+                        self->details_label);
+    gtk_widget_set_visible (self->details_label_widget, details_visible);
 }
 
 void
 nautilus_floating_bar_remove_hover_timeout (NautilusFloatingBar *self)
 {
-    if (self->priv->hover_timeout_id != 0)
+    if (self->hover_timeout_id != 0)
     {
-        g_source_remove (self->priv->hover_timeout_id);
-        self->priv->hover_timeout_id = 0;
+        g_source_remove (self->hover_timeout_id);
+        self->hover_timeout_id = 0;
     }
 }
 
@@ -212,7 +214,7 @@ check_pointer_timeout (gpointer user_data)
     if (pointer_y == -1 || pointer_y < data->y_down_limit || pointer_y > data->y_upper_limit)
     {
         gtk_widget_show (data->floating_bar);
-        NAUTILUS_FLOATING_BAR (data->floating_bar)->priv->hover_timeout_id = 0;
+        NAUTILUS_FLOATING_BAR (data->floating_bar)->hover_timeout_id = 0;
 
         return G_SOURCE_REMOVE;
     }
@@ -225,27 +227,31 @@ check_pointer_timeout (gpointer user_data)
 }
 
 static gboolean
-overlay_enter_notify_cb (GtkWidget        *parent,
-                         GdkEventCrossing *event,
-                         gpointer          user_data)
+overlay_event_cb (GtkWidget *parent,
+                  GdkEvent  *event,
+                  gpointer   user_data)
 {
+    NautilusFloatingBar *self = NAUTILUS_FLOATING_BAR (user_data);
     GtkWidget *widget = user_data;
     CheckPointerData *data;
     gint y_pos;
 
-    NautilusFloatingBar *self = NAUTILUS_FLOATING_BAR (widget);
-
-    if (self->priv->hover_timeout_id != 0)
-    {
-        g_source_remove (self->priv->hover_timeout_id);
-    }
-
-    if (event->window != gtk_widget_get_window (widget))
+    if (gdk_event_get_event_type (event) != GDK_ENTER_NOTIFY)
     {
         return GDK_EVENT_PROPAGATE;
     }
 
-    if (NAUTILUS_FLOATING_BAR (widget)->priv->is_interactive)
+    if (self->hover_timeout_id != 0)
+    {
+        g_source_remove (self->hover_timeout_id);
+    }
+
+    if (gdk_event_get_window (event) != gtk_widget_get_window (widget))
+    {
+        return GDK_EVENT_PROPAGATE;
+    }
+
+    if (self->is_interactive)
     {
         return GDK_EVENT_PROPAGATE;
     }
@@ -255,15 +261,15 @@ overlay_enter_notify_cb (GtkWidget        *parent,
     data = g_slice_new (CheckPointerData);
     data->overlay = parent;
     data->floating_bar = widget;
-    data->device = gdk_event_get_device ((GdkEvent *) event);
+    data->device = gdk_event_get_device (event);
     data->y_down_limit = y_pos;
     data->y_upper_limit = y_pos + gtk_widget_get_allocated_height (widget);
 
-    self->priv->hover_timeout_id = g_timeout_add_full (G_PRIORITY_DEFAULT, HOVER_HIDE_TIMEOUT_INTERVAL,
-                                                       check_pointer_timeout, data,
-                                                       check_pointer_data_free);
+    self->hover_timeout_id = g_timeout_add_full (G_PRIORITY_DEFAULT, HOVER_HIDE_TIMEOUT_INTERVAL,
+                                                 check_pointer_timeout, data,
+                                                 check_pointer_data_free);
 
-    g_source_set_name_by_id (self->priv->hover_timeout_id, "[nautilus-floating-bar] overlay_enter_notify_cb");
+    g_source_set_name_by_id (self->hover_timeout_id, "[nautilus-floating-bar] overlay_event_cb");
 
     return GDK_EVENT_STOP;
 }
@@ -279,13 +285,13 @@ nautilus_floating_bar_parent_set (GtkWidget *widget,
     if (old_parent != NULL)
     {
         g_signal_handlers_disconnect_by_func (old_parent,
-                                              overlay_enter_notify_cb, widget);
+                                              overlay_event_cb, widget);
     }
 
     if (parent != NULL)
     {
-        g_signal_connect (parent, "enter-notify-event",
-                          G_CALLBACK (overlay_enter_notify_cb), widget);
+        g_signal_connect (parent, "event",
+                          G_CALLBACK (overlay_event_cb), widget);
     }
 }
 
@@ -392,9 +398,9 @@ nautilus_floating_bar_constructed (GObject *obj)
 
     w = gtk_spinner_new ();
     gtk_box_pack_start (GTK_BOX (box), w, FALSE, FALSE, 0);
-    gtk_widget_set_visible (w, self->priv->show_spinner);
+    gtk_widget_set_visible (w, self->show_spinner);
     gtk_spinner_start (GTK_SPINNER (w));
-    self->priv->spinner = w;
+    self->spinner = w;
 
     gtk_widget_set_size_request (w, 16, 16);
     gtk_widget_set_margin_start (w, 8);
@@ -413,13 +419,13 @@ nautilus_floating_bar_constructed (GObject *obj)
     gtk_label_set_ellipsize (GTK_LABEL (w), PANGO_ELLIPSIZE_MIDDLE);
     gtk_label_set_single_line_mode (GTK_LABEL (w), TRUE);
     gtk_container_add (GTK_CONTAINER (labels_box), w);
-    self->priv->primary_label_widget = w;
+    self->primary_label_widget = w;
     gtk_widget_show (w);
 
     w = gtk_label_new (NULL);
     gtk_label_set_single_line_mode (GTK_LABEL (w), TRUE);
     gtk_container_add (GTK_CONTAINER (labels_box), w);
-    self->priv->details_label_widget = w;
+    self->details_label_widget = w;
     gtk_widget_show (w);
 }
 
@@ -428,9 +434,6 @@ nautilus_floating_bar_init (NautilusFloatingBar *self)
 {
     GtkStyleContext *context;
 
-    self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, NAUTILUS_TYPE_FLOATING_BAR,
-                                              NautilusFloatingBarDetails);
-
     context = gtk_widget_get_style_context (GTK_WIDGET (self));
     gtk_style_context_add_class (context, "floating-bar");
 }
@@ -480,7 +483,6 @@ nautilus_floating_bar_class_init (NautilusFloatingBarClass *klass)
                       G_TYPE_NONE, 1,
                       G_TYPE_INT);
 
-    g_type_class_add_private (klass, sizeof (NautilusFloatingBarDetails));
     g_object_class_install_properties (oclass, NUM_PROPERTIES, properties);
 }
 
@@ -488,10 +490,10 @@ void
 nautilus_floating_bar_set_primary_label (NautilusFloatingBar *self,
                                          const gchar         *label)
 {
-    if (g_strcmp0 (self->priv->primary_label, label) != 0)
+    if (g_strcmp0 (self->primary_label, label) != 0)
     {
-        g_free (self->priv->primary_label);
-        self->priv->primary_label = g_strdup (label);
+        g_free (self->primary_label);
+        self->primary_label = g_strdup (label);
 
         g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_PRIMARY_LABEL]);
 
@@ -503,10 +505,10 @@ void
 nautilus_floating_bar_set_details_label (NautilusFloatingBar *self,
                                          const gchar         *label)
 {
-    if (g_strcmp0 (self->priv->details_label, label) != 0)
+    if (g_strcmp0 (self->details_label, label) != 0)
     {
-        g_free (self->priv->details_label);
-        self->priv->details_label = g_strdup (label);
+        g_free (self->details_label);
+        self->details_label = g_strdup (label);
 
         g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_DETAILS_LABEL]);
 
@@ -527,10 +529,10 @@ void
 nautilus_floating_bar_set_show_spinner (NautilusFloatingBar *self,
                                         gboolean             show_spinner)
 {
-    if (self->priv->show_spinner != show_spinner)
+    if (self->show_spinner != show_spinner)
     {
-        self->priv->show_spinner = show_spinner;
-        gtk_widget_set_visible (self->priv->spinner,
+        self->show_spinner = show_spinner;
+        gtk_widget_set_visible (self->spinner,
                                 show_spinner);
 
         g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_SHOW_SPINNER]);
@@ -573,7 +575,7 @@ nautilus_floating_bar_add_action (NautilusFloatingBar *self,
     g_signal_connect (button, "clicked",
                       G_CALLBACK (action_button_clicked_cb), self);
 
-    self->priv->is_interactive = TRUE;
+    self->is_interactive = TRUE;
 }
 
 void
@@ -601,5 +603,5 @@ nautilus_floating_bar_cleanup_actions (NautilusFloatingBar *self)
 
     g_list_free (children);
 
-    self->priv->is_interactive = FALSE;
+    self->is_interactive = FALSE;
 }
