@@ -19,8 +19,7 @@
  *
  */
 
-#ifndef NAUTILUS_SEARCH_ENGINE_MODEL_H
-#define NAUTILUS_SEARCH_ENGINE_MODEL_H
+#pragma once
 
 #include "nautilus-directory.h"
 
@@ -30,6 +29,4 @@ G_DECLARE_FINAL_TYPE (NautilusSearchEngineModel, nautilus_search_engine_model, N
 NautilusSearchEngineModel* nautilus_search_engine_model_new       (void);
 void                       nautilus_search_engine_model_set_model (NautilusSearchEngineModel *model,
 								   NautilusDirectory         *directory);
-NautilusDirectory *        nautilus_search_engine_model_get_model (NautilusSearchEngineModel *model);
-
-#endif /* NAUTILUS_SEARCH_ENGINE_MODEL_H */
+NautilusDirectory *        nautilus_search_engine_model_get_model (NautilusSearchEngineModel *model);
\ No newline at end of file
