@@ -25,6 +25,7 @@
 #include "nautilus-search-engine-private.h"
 #include "nautilus-search-hit.h"
 #include "nautilus-search-provider.h"
+#include "nautilus-tracker-utilities.h"
 #define DEBUG_FLAG NAUTILUS_DEBUG_SEARCH
 #include "nautilus-debug.h"
 
@@ -77,8 +78,9 @@ finalize (GObject *object)
     }
 
     g_clear_object (&tracker->query);
-    g_clear_object (&tracker->connection);
     g_queue_free_full (tracker->hits_pending, g_object_unref);
+    /* This is a singleton, no need to unref. */
+    tracker->connection = NULL;
 
     G_OBJECT_CLASS (nautilus_search_engine_tracker_parent_class)->finalize (object);
 }
@@ -292,6 +294,31 @@ search_finished_idle (gpointer user_data)
  */
 #define FILENAME_RANK "5.0"
 
+static gchar *
+filter_alnum_strdup (gchar *string)
+{
+    GString *filtered;
+    gchar *c;
+
+    filtered = g_string_new ("");
+    for (c = string; *c; c = g_utf8_next_char (c))
+    {
+        gunichar uc;
+
+        uc = g_utf8_get_char (c);
+        if (g_unichar_isalnum (uc))
+        {
+            g_string_append_unichar (filtered, uc);
+        }
+        else
+        {
+            g_string_append_c (filtered, ' ');
+        }
+    }
+
+    return g_string_free (filtered, FALSE);
+}
+
 static void
 nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
 {
@@ -334,43 +361,56 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
     mimetypes = nautilus_query_get_mime_types (tracker->query);
 
     sparql = g_string_new ("SELECT DISTINCT"
-                           " nie:url(?urn)"
+                           " ?url"
                            " xsd:double(COALESCE(?rank2, ?rank1)) AS ?rank"
-                           " nfo:fileLastModified(?urn)"
-                           " nfo:fileLastAccessed(?urn)");
+                           " nfo:fileLastModified(?file)"
+                           " nfo:fileLastAccessed(?file)");
+
+    if (tracker->fts_enabled && *search_text)
+    {
+        g_string_append (sparql, " fts:snippet(?content)");
+    }
+
+    g_string_append (sparql, "FROM tracker:FileSystem ");
 
     if (tracker->fts_enabled)
     {
-        g_string_append (sparql, " fts:snippet(?urn)");
+        g_string_append (sparql, "FROM tracker:Documents ");
     }
 
     g_string_append (sparql,
                      "\nWHERE {"
-                     "  ?urn a nfo:FileDataObject;"
+                     "  ?file a nfo:FileDataObject;"
                      "  nfo:fileLastModified ?mtime;"
                      "  nfo:fileLastAccessed ?atime;"
-                     "  tracker:available true;"
-                     "  nie:url ?url");
+                     "  nie:dataSource/tracker:available true;"
+                     "  nie:url ?url.");
 
     if (mimetypes->len > 0)
     {
-        g_string_append (sparql, "; nie:mimeType ?mime");
+        g_string_append (sparql,
+                         "  ?content nie:isStoredAs ?file;"
+                         "    nie:mimeType ?mime");
     }
 
-    if (tracker->fts_enabled)
+    if (tracker->fts_enabled && *search_text)
     {
         /* Use fts:match only for content search to not lose some filename results due to stop words. */
+        g_autofree gchar *filtered_search_text;
+
+        filtered_search_text = filter_alnum_strdup (search_text);
         g_string_append_printf (sparql,
-                                " {"
-                                " ?urn fts:match '\"nie:plainTextContent\" : \"%s\"*' ."
-                                " BIND(fts:rank(?urn) AS ?rank1) ."
+                                " { "
+                                " ?content nie:isStoredAs ?file ."
+                                " ?content fts:match \"%s*\" ."
+                                " BIND(fts:rank(?content) AS ?rank1) ."
                                 " } UNION",
-                                search_text);
+                                filtered_search_text);
     }
 
     g_string_append_printf (sparql,
                             " {"
-                            " ?urn nfo:fileName ?filename ."
+                            " ?file nfo:fileName ?filename ."
                             " FILTER(fn:contains(fn:lower-case(?filename), '%s')) ."
                             " BIND(" FILENAME_RANK " AS ?rank2) ."
                             " }",
@@ -384,7 +424,10 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
     }
     else
     {
-        g_string_append_printf (sparql, "tracker:uri-is-descendant('%s', ?url)", location_uri);
+        /* STRSTARTS is faster than tracker:uri-is-descendant().
+         * See https://gitlab.gnome.org/GNOME/tracker/-/issues/243
+         */
+        g_string_append_printf (sparql, "STRSTARTS(?url, '%s/')", location_uri);
     }
 
     date_range = nautilus_query_get_date_range (tracker->query);
@@ -558,8 +601,7 @@ nautilus_search_engine_tracker_init (NautilusSearchEngineTracker *engine)
 
     engine->hits_pending = g_queue_new ();
 
-    engine->connection = tracker_sparql_connection_get (NULL, &error);
-
+    engine->connection = nautilus_tracker_get_miner_fs_connection (&error);
     if (error)
     {
         g_warning ("Could not establish a connection to Tracker: %s", error->message);
