@@ -367,14 +367,14 @@ search_fts_mode_changed (GtkToggleButton       *button,
         popover->fts_enabled == FALSE)
     {
         popover->fts_enabled = TRUE;
-        g_settings_set_boolean(nautilus_preferences, NAUTILUS_PREFERENCES_FTS_ENABLED, TRUE);
+        g_settings_set_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_FTS_ENABLED, TRUE);
         g_object_notify (G_OBJECT (popover), "fts-enabled");
     }
     else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (popover->filename_search_button)) &&
              popover->fts_enabled == TRUE)
     {
         popover->fts_enabled = FALSE;
-        g_settings_set_boolean(nautilus_preferences, NAUTILUS_PREFERENCES_FTS_ENABLED, FALSE);
+        g_settings_set_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_FTS_ENABLED, FALSE);
         g_object_notify (G_OBJECT (popover), "fts-enabled");
     }
 }
@@ -793,7 +793,7 @@ nautilus_search_popover_class_init (NautilusSearchPopoverClass *klass)
                                         g_cclosure_marshal_generic,
                                         G_TYPE_NONE,
                                         1,
-                                        G_TYPE_POINTER);
+                                        G_TYPE_PTR_ARRAY);
 
     signals[MIME_TYPE] = g_signal_new ("mime-type",
                                        NAUTILUS_TYPE_SEARCH_POPOVER,
@@ -805,7 +805,7 @@ nautilus_search_popover_class_init (NautilusSearchPopoverClass *klass)
                                        G_TYPE_NONE,
                                        2,
                                        G_TYPE_INT,
-                                       G_TYPE_POINTER);
+                                       G_TYPE_STRING);
 
     signals[TIME_TYPE] = g_signal_new ("time-type",
                                        NAUTILUS_TYPE_SEARCH_POPOVER,
