@@ -114,6 +114,7 @@ struct _NautilusToolbar
     NautilusWindowSlot *window_slot;
     GBinding *icon_binding;
     GBinding *search_binding;
+    GBinding *tooltip_binding;
 };
 
 enum
@@ -131,7 +132,7 @@ G_DEFINE_TYPE (NautilusToolbar, nautilus_toolbar, GTK_TYPE_HEADER_BAR);
 
 static void nautilus_toolbar_set_window_slot_real (NautilusToolbar    *self,
                                                    NautilusWindowSlot *slot);
-static void update_operations                     (NautilusToolbar    *self);
+static void update_operations (NautilusToolbar *self);
 
 static void
 toolbar_update_appearance (NautilusToolbar *self)
@@ -195,7 +196,7 @@ fill_menu (NautilusToolbar *self,
     GList *list;
 
     list = back ? nautilus_window_slot_get_back_history (self->window_slot) :
-                  nautilus_window_slot_get_forward_history (self->window_slot);
+           nautilus_window_slot_get_forward_history (self->window_slot);
 
     index = 0;
     while (list != NULL)
@@ -1202,19 +1203,19 @@ nautilus_toolbar_class_init (NautilusToolbarClass *klass)
                               G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
     properties [PROP_WINDOW_SLOT] =
-      g_param_spec_object ("window-slot",
-                           "Window slot currently active",
-                           "Window slot currently acive",
-                           NAUTILUS_TYPE_WINDOW_SLOT,
-                           (G_PARAM_READWRITE |
-                            G_PARAM_STATIC_STRINGS));
+        g_param_spec_object ("window-slot",
+                             "Window slot currently active",
+                             "Window slot currently acive",
+                             NAUTILUS_TYPE_WINDOW_SLOT,
+                             (G_PARAM_READWRITE |
+                              G_PARAM_STATIC_STRINGS));
 
     properties [PROP_SEARCHING] =
-      g_param_spec_boolean ("searching",
-                            "Current view is searching",
-                            "Whether the current view is searching or not",
-                            FALSE,
-                            G_PARAM_READWRITE);
+        g_param_spec_boolean ("searching",
+                              "Current view is searching",
+                              "Whether the current view is searching or not",
+                              FALSE,
+                              G_PARAM_READWRITE);
 
     g_object_class_install_properties (oclass, NUM_PROPERTIES, properties);
 
@@ -1340,9 +1341,9 @@ on_slot_toolbar_menu_sections_changed (NautilusToolbar    *self,
                             new_sections->extended_section, FALSE, FALSE, 0);
     }
 
-    gtk_widget_set_sensitive (self->view_button, new_sections->extended_section != NULL ||
-                                                 new_sections->zoom_section != NULL ||
-                                                 new_sections->supports_undo_redo);
+    gtk_widget_set_sensitive (self->view_button, (new_sections->extended_section != NULL ||
+                                                  new_sections->zoom_section != NULL ||
+                                                  new_sections->supports_undo_redo));
 }
 
 
@@ -1379,6 +1380,26 @@ nautilus_toolbar_view_toggle_icon_transform_to (GBinding     *binding,
     return TRUE;
 }
 
+static gboolean
+nautilus_toolbar_view_toggle_tooltip_transform_to (GBinding     *binding,
+                                                   const GValue *from_value,
+                                                   GValue       *to_value,
+                                                   gpointer      user_data)
+{
+    const gchar *tooltip;
+
+    tooltip = g_value_get_string (from_value);
+
+    /* As per design decision, we let the previous used tooltip if no
+     * view menu is available */
+    if (tooltip)
+    {
+        g_value_set_string (to_value, tooltip);
+    }
+
+    return TRUE;
+}
+
 /* Called from on_window_slot_destroyed(), since bindings and signal handlers
  * are automatically removed once the slot goes away.
  */
@@ -1404,6 +1425,14 @@ nautilus_toolbar_set_window_slot_real (NautilusToolbar    *self,
                                                           self,
                                                           NULL);
 
+        self->tooltip_binding = g_object_bind_property_full (self->window_slot, "tooltip",
+                                                             self->view_toggle_button, "tooltip-text",
+                                                             G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE,
+                                                             (GBindingTransformFunc) nautilus_toolbar_view_toggle_tooltip_transform_to,
+                                                             NULL,
+                                                             self,
+                                                             NULL);
+
         self->search_binding = g_object_bind_property (self->window_slot, "searching",
                                                        self, "searching",
                                                        G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
@@ -1417,7 +1446,6 @@ nautilus_toolbar_set_window_slot_real (NautilusToolbar    *self,
                                   G_CALLBACK (slot_on_templates_menu_changed), self);
         g_signal_connect_swapped (self->window_slot, "notify::searching",
                                   G_CALLBACK (toolbar_update_appearance), self);
-
     }
 
     children = gtk_container_get_children (GTK_CONTAINER (self->search_container));
