@@ -1,5 +1,4 @@
-#ifndef NAUTILUS_VIEW_ICON_ITEM_UI_H
-#define NAUTILUS_VIEW_ICON_ITEM_UI_H
+#pragma once
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -17,6 +16,3 @@ NautilusViewIconItemUi * nautilus_view_icon_item_ui_new (NautilusViewItemModel *
 NautilusViewItemModel * nautilus_view_icon_item_ui_get_model (NautilusViewIconItemUi *self);
 
 G_END_DECLS
-
-#endif /* NAUTILUS_VIEW_ICON_ITEM_UI_H */
-
