@@ -1,5 +1,4 @@
-#ifndef NAUTILUS_VIEW_MODEL_H
-#define NAUTILUS_VIEW_MODEL_H
+#pragma once
 
 #include <glib.h>
 #include "nautilus-file.h"
@@ -37,9 +36,5 @@ void nautilus_view_model_add_item (NautilusViewModel     *self,
                                    NautilusViewItemModel *item);
 void nautilus_view_model_add_items (NautilusViewModel *self,
                                     GQueue            *items);
-void nautilus_view_model_set_items (NautilusViewModel *self,
-                                    GQueue            *items);
+
 G_END_DECLS
-
-#endif /* NAUTILUS_VIEW_MODEL_H */
-
